@@ -11,7 +11,7 @@
 
 package Exception::Stringy;
 {
-  $Exception::Stringy::VERSION = '0.18';
+  $Exception::Stringy::VERSION = '0.19';
 }
 use strict;
 use warnings;
@@ -69,9 +69,13 @@ sub import {
 
     my $method_prefix = dor($options{method_prefix}, 'x');
 
-    do {
+    foreach (@symbols) {
+        defined ${"${caller}::${method_prefix}$_"}
+          and next;
+        defined ${"${class}::_symbol_$_"}
+          or next;
         *{"${caller}::${method_prefix}$_"} = \${"${class}::_symbol_$_"}
-        } foreach @symbols;
+    } 
 
     foreach my $k (keys %throw_aliases) {
         my $v = $throw_aliases{$k};
@@ -170,7 +174,7 @@ sub registered_exception_classes { keys %registered }
 # fake methods (class methods with exception as first argument)
 
 $_symbol_throw   = sub { croak $_[0] };
-$_symbol_rethrow = sub { croak $_[0] };
+$_symbol_rethrow = sub { die $_[0] };
 $_symbol_raise   = sub { croak $_[0] };
 
 $_symbol_class = sub {
@@ -250,7 +254,7 @@ Exception::Stringy - a Perl Exceptions module where exceptions are not objects b
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
